@@ -16,13 +16,17 @@ app = typer.Typer()
 try:
     api = api_core.API()
     initialized = api.start_check()
+    api.set_schema()
     api.commit('',False)
 except:
     print(f'Stack has not been installed yet!')
     print(f'setting-up Stack...')
     api = api_core.API()
     initialized = api.start_check()
-
+    try:
+        api.set_schema()
+    except:
+        pass
     if initialized:
         api.commit('First commit')
 
@@ -38,31 +42,31 @@ def connect_cli(uri: str):
     print('- Connecting remote dataset... -')
     print('--------------------------------')
     
-    try:
-        if docker_ver():
-            assert(False)
+    # try:
+    if docker_ver():
+        assert(False)
 
-        assert(not '.stack' in uri)
+    assert(not '.stack' in uri)
 
-        if uri == '.':
-            uri = str(os.path.abspath('.'))
-        if uri[0:2] == '~/':
-            uri = str(os.path.abspath('~/'))
-        if uri[0:3] == 'C:/' or uri[0:3] == 'C:\\':
-            uri[0:3] = '/c/'
+    if uri == '.':
+        uri = str(os.path.abspath('.'))
+    if uri[0:2] == '~/':
+        uri = str(os.path.abspath('~/'))
+    if uri[0:3] == 'C:/' or uri[0:3] == 'C:\\':
+        uri[0:3] = '/c/'
 
-        uri = uri.replace(path_home,'')
+    uri = uri.replace(path_home,'')
 
-        api.init(uri)
-        api.connect_post_cli()
-        api.set_schema()
-        api.reset_version()
-        print('connection succesful')
-        return {'success': True}
-    except:
-        print('connection unsuccesful!')
+    api.init(uri)
+    api.connect_post_cli()
+    api.set_schema()
+    api.reset_version()
+    print('connection succesful')
+    return {'success': True}
+    # except:
+        # print('connection unsuccesful!')
 
-        return {'success': False}
+        # return {'success': False}
 
 @app.command("put")
 def put_command(file: str, target_subpath: str=''):
@@ -186,7 +190,7 @@ def branch_cli(uri: str, name: str = '', filter_json: str = '', type: str = 'cop
         return {'success': False}
 
 @app.command("merge")
-def merge_cli(child: str, parent: str = ''):
+def merge_cli(child: str = '', parent: str = ''):
     '''
         Merge a child branch of the dataset from the CLI and adds its changes to
         the a parent branch (us)
@@ -224,14 +228,17 @@ def merge_cli(child: str, parent: str = ''):
 @app.command("checkpoints")
 def get_versions_command():
     try:
-        print(api.get_versions())
+        versions = api.get_versions()
+        for v in reversed(list(versions.keys())):
+            if v != 'current_v':
+                print(f"-- Version: {v} - Label: '{versions[v]['label']}' - Date: {versions[v]['date']} ")
     except:
         return {}
 
 @app.command("add_checkpoint")
 def add_version_command(name: str= ''):
     try:
-        return {'success': api.add_version()}
+        return {'success': api.add_version(name)}
     except:
         return {} 
 
@@ -272,7 +279,7 @@ def uri_api():
     '''
         Gets the URI of the current dataset connected
     '''
-    uri = api.getURI()
+    uri = api.config
     print('Current dataset: ' + uri['dataset'])
     print('Current storage: ' + uri['storage'])
 
